@@ -76,6 +76,10 @@ class TestPostgres(Validator):
         self.validate_identity("SELECT CURRENT_SCHEMA")
         self.validate_identity("SELECT CURRENT_USER")
         self.validate_identity("SELECT * FROM ONLY t1")
+        self.validate_identity("SELECT INTERVAL '-1 MONTH'")
+        self.validate_identity(
+            "SELECT * FROM test_data, LATERAL JSONB_ARRAY_ELEMENTS(data) WITH ORDINALITY AS elem(value, ordinality)"
+        )
         self.validate_identity(
             "SELECT id, name FROM xml_data AS t, XMLTABLE('/root/user' PASSING t.xml COLUMNS id INT PATH '@id', name TEXT PATH 'name/text()') AS x"
         )
@@ -565,7 +569,7 @@ FROM json_data, field_ids""",
             "x ^ y",
             write={
                 "": "POWER(x, y)",
-                "postgres": "x ^ y",
+                "postgres": "POWER(x, y)",
             },
         )
         self.validate_all(
@@ -762,7 +766,7 @@ FROM json_data, field_ids""",
             "x / y ^ z",
             write={
                 "": "x / POWER(y, z)",
-                "postgres": "x / y ^ z",
+                "postgres": "x / POWER(y, z)",
             },
         )
         self.validate_all(
